<?php
/**
 * Rikke functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Rikke
 */

if ( ! function_exists( 'rikke_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function rikke_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Rikke, use a find and replace
	 * to change 'rikke' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'rikke', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size('rikke-large-thumb', 680);
	add_image_size('rikke-small-thumb', 740);	

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'rikke' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'rikke_custom_background_args', array(
		'default-color' => 'f7f7f7',
		'default-image' => '',
	) ) );

	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 200,
		'flex-height' => true,
	) );

}
endif; // rikke_setup
add_action( 'after_setup_theme', 'rikke_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function rikke_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'rikke_content_width', 1170 );
}
add_action( 'after_setup_theme', 'rikke_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rikke_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'rikke' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );

	//Custom widgets
	register_widget( 'Rikke_Video_Widget' );
	register_widget( 'Rikke_Recent_Posts' );

}
add_action( 'widgets_init', 'rikke_widgets_init' );

/**
 * Custom widgets
 */
require get_template_directory() . "/widgets/video-widget.php";
require get_template_directory() . "/widgets/posts-widget.php";
/**
 * Enqueue scripts and styles.
 */
function rikke_scripts() {
	
	wp_enqueue_style( 'rikke-style', get_stylesheet_uri() );

	wp_enqueue_style( 'rikke-fonts', esc_url( rikke_fonts_url() ), array(), null );

	wp_enqueue_style( 'rikke-elegant-icons', get_template_directory_uri() . '/fonts/style.css' );		

	wp_enqueue_script( 'rikke-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'rikke-scripts', get_template_directory_uri() . '/js/scripts.js', array('jquery'), '', true );

	wp_enqueue_script( 'rikke-main', get_template_directory_uri() . '/js/main.min.js', array('jquery'), '', true );

	if ( rikke_blog_layout() == 'masonry-layout' && (is_home() || is_archive()) ) {
		wp_enqueue_script( 'rikke-masonry-init', get_template_directory_uri() . '/js/masonry-init.js', array('jquery-masonry'), '', true );		
	}

	wp_enqueue_script( 'rikke-html5shiv', get_template_directory_uri() . '/js/html5.js', array(), '', true );
    wp_script_add_data( 'rikke-html5shiv', 'conditional', 'lt IE 9' );

}
add_action( 'wp_enqueue_scripts', 'rikke_scripts' );

/**
 * Enqueue Bootstrap
 */
function rikke_enqueue_bootstrap() {
	wp_enqueue_style( 'rikke-bootstrap', get_template_directory_uri() . '/css/bootstrap/bootstrap.min.css', array(), true );
}
add_action( 'wp_enqueue_scripts', 'rikke_enqueue_bootstrap', 9 );

/**
 * Google Fonts - adapted from TwentySixteen
 *
 */
if ( ! function_exists( 'rikke_fonts_url' ) ) :
function rikke_fonts_url() {

	$fonts_url 		= '';
	$subsets   		= 'latin,latin-ext,cyrillic'; //Fallback for browsers with no unicode-range support
	$weights 		= array( '400', '400italic', '600', '600italic' );
	$weights 		= implode(',', $weights);
	$body_font 		= get_theme_mod('body_font_family', 'Inconsolata');
	$headings_font 	= get_theme_mod('headings_font_family', 'Josefin Sans');
	$fonts     		= array();
	$fonts[] 		= esc_attr($body_font) . ':' . esc_attr($weights);
	$fonts[] 		= esc_attr($headings_font) . ':' . esc_attr($weights);

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions
 */
require get_template_directory() . '/inc/functions/functions-blog.php';
require get_template_directory() . '/inc/functions/functions-footer.php';
require get_template_directory() . '/inc/functions/functions-header.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Styles
 */
require get_template_directory() . '/inc/styles.php';