<?php
/**
 * Rikke Theme Customizer.
 *
 * @package Rikke
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function rikke_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
    $wp_customize->remove_control( 'header_textcolor' );


    //Titles
    class Rikke_Info extends WP_Customize_Control {
        public $type = 'info';
        public $label = '';
        public function render_content() {
        ?>
            <h3 style="margin-top:30px;background-color:#343540;padding:5px;color:#fff;text-align:center;text-transform:uppercase;"><?php echo esc_html( $this->label ); ?></h3>
        <?php
        }
    }

    /* Sections */
    $sections = array(
        //Fonts
        'rikke_fonts'   => array(
            'slug'         => 'rikke_fonts',
            'title'        => __('Fonts', 'rikke'),
            'panel'        => '',
            'description'  => __('For help selecting fonts see the <a href="http://theme.blue/documentation/rikke" target="_blank">documentation</a>. Please note that your font selection applies to theme elements. The font list is here: google.com/fonts', 'rikke'),
            'priority'     => 20,
        ),                  
        //Blog
        'rikke_blog'       => array(
            'slug'         => 'rikke_blog',
            'title'        => __('Blog', 'rikke'),
            'panel'        => '',
            'description'  => '',
            'priority'     => 21,
        ),               
    );

    foreach ( $sections as $key => $section ) {
        $wp_customize->add_section(
            $section['slug'],
            array(
                'title'         => $section['title'],
                'description'   => $section['description'],
                'panel'         => $section['panel'],
                'priority'      => $section['priority']
            )
        );
    }

    /* Controls */

    //Label - Blog layout
    $wp_customize->add_setting('rikke_options[info]', array(
            'type'              => 'info_control',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',            
        )
    );
    $wp_customize->add_control( new Rikke_Info( $wp_customize, 'layout', array(
        'label' => __('Layout', 'rikke'),
        'section' => 'rikke_blog',
        'settings' => 'rikke_options[info]',
        'priority' => 10
        ) )
    );    
    //Label - Excerpt
    $wp_customize->add_setting('rikke_options[info]', array(
            'type'              => 'info_control',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',            
        )
    );
    $wp_customize->add_control( new Rikke_Info( $wp_customize, 'content', array(
        'label' => __('Excerpt', 'rikke'),
        'section' => 'rikke_blog',
        'settings' => 'rikke_options[info]',
        'priority' => 14
        ) )
    );      
    //Label - Meta
    $wp_customize->add_setting('rikke_options[info]', array(
            'type'              => 'info_control',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',            
        )
    );
    $wp_customize->add_control( new Rikke_Info( $wp_customize, 'meta', array(
        'label' => __('Meta', 'rikke'),
        'section' => 'rikke_blog',
        'settings' => 'rikke_options[info]',
        'priority' => 17
        ) )
    ); 
    //Label - Featured images
    $wp_customize->add_setting('rikke_options[info]', array(
            'type'              => 'info_control',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',            
        )
    );
    $wp_customize->add_control( new Rikke_Info( $wp_customize, 'feat_images', array(
        'label' => __('Featured images', 'rikke'),
        'section' => 'rikke_blog',
        'settings' => 'rikke_options[info]',
        'priority' => 20
        ) )
    ); 

    //Controls
    $controls = array(
        //Blog
        'blog_layout' => array(
            'slug'          => 'blog_layout',
            'section'       => 'rikke_blog',
            'sanitize'      => 'rikke_sanitize_blog',
            'default'       => 'default',
            'type'          => 'radio',
            'label'         => __('Blog layout', 'rikke'),
            'description'   => '',
            'choices'       => array(
                'default'           => __( 'Default', 'rikke' ),
                'masonry-layout'    => __( 'Masonry', 'rikke' )
            ),
            'priority'      => 11,
        ),
        'sidebar_position' => array(
            'slug'          => 'sidebar_position',
            'section'       => 'rikke_blog',
            'sanitize'      => 'rikke_sanitize_sidebar',
            'default'       => 'right',
            'type'          => 'radio',
            'label'         => __('Sidebar position', 'rikke'),
            'description'   => '',
            'choices'       => array(
                'left'    => __( 'Left', 'rikke' ),
                'right'   => __( 'Right', 'rikke' ),
            ),
            'priority'      => 13,
        ),
        'exc_length' => array(
            'slug'          => 'exc_length',
            'section'       => 'rikke_blog',
            'sanitize'      => 'absint',
            'default'       => '30',
            'type'          => 'number',
            'label'         => __('Excerpt length', 'rikke'),
            'description'   => __('Excerpt length [default: 30 words]', 'rikke'),
            'choices'       => '',
            'input_attrs'   => array(
                'min'   => 10,
                'max'   => 200,
                'step'  => 5,
                'style' => 'padding: 15px;',
            ),            
            'priority'      => 15,
        ),        
        'custom_read_more' => array(
            'slug'          => 'custom_read_more',
            'section'       => 'rikke_blog',
            'sanitize'      => 'rikke_sanitize_text',
            'default'       => '',
            'type'          => 'text',
            'label'         => __( 'Read more text', 'rikke' ),
            'description'   => __( 'Add some text here to replace the default [&hellip;]. It will automatically be linked to your article', 'rikke' ),
            'choices'       => '',
            'priority'      => 16,
        ),
        'hide_meta_index' => array(
            'slug'          => 'hide_meta_index',
            'section'       => 'rikke_blog',
            'sanitize'      => 'rikke_sanitize_checkbox',
            'default'       => '',
            'type'          => 'checkbox',
            'label'         => __('Hide post meta on the blog?', 'rikke'),
            'description'   => '',
            'choices'       => '',
            'priority'      => 18,
        ),
        'hide_meta_single' => array(
            'slug'          => 'hide_meta_single',
            'section'       => 'rikke_blog',
            'sanitize'      => 'rikke_sanitize_checkbox',
            'default'       => '',
            'type'          => 'checkbox',
            'label'         => __('Hide post meta on single posts?', 'rikke'),
            'description'   => '',
            'choices'       => '',
            'priority'      => 19,
        ),
        'index_feat_image' => array(
            'slug'          => 'index_feat_image',
            'section'       => 'rikke_blog',
            'sanitize'      => 'rikke_sanitize_checkbox',
            'default'       => '',
            'type'          => 'checkbox',
            'label'         => __('Hide featured images on the blog?', 'rikke'),
            'description'   => '',
            'choices'       => '',
            'priority'      => 21,
        ),
        'post_feat_image' => array(
            'slug'          => 'post_feat_image',
            'section'       => 'rikke_blog',
            'sanitize'      => 'rikke_sanitize_checkbox',
            'default'       => '',
            'type'          => 'checkbox',
            'label'         => __('Hide featured images on single posts?', 'rikke'),
            'description'   => '',
            'choices'       => '',
            'priority'      => 22,
        ),
        //Fonts 
        'body_font_family' => array(
            'slug'          => 'body_font_family',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'rikke_sanitize_text',
            'default'       => 'Inconsolata',
            'type'          => 'text',
            'label'         => __( 'Body font', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 11,
        ),
        'headings_font_family' => array(
            'slug'          => 'headings_font_family',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'rikke_sanitize_text',
            'default'       => 'Josefin Sans',
            'type'          => 'text',
            'label'         => __( 'Headings font', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 13,
        ),

        'h1_size' => array(
            'slug'          => 'h1_size',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'absint',
            'default'       => '36',
            'type'          => 'number',
            'label'         => __( 'H1 size', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 14,
            'input_attrs' => array(
                'min'   => 10,
                'max'   => 60,
                'step'  => 1,
                'style' => 'margin-bottom: 15px; padding: 10px;',
            ),            
        ),
        'h2_size' => array(
            'slug'          => 'h2_size',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'absint',
            'default'       => '30',
            'type'          => 'number',
            'label'         => __( 'H2 size', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 15,
            'input_attrs' => array(
                'min'   => 10,
                'max'   => 60,
                'step'  => 1,
                'style' => 'margin-bottom: 15px; padding: 10px;',
            ),            
        ),  
        'h3_size' => array(
            'slug'          => 'h3_size',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'absint',
            'default'       => '24',
            'type'          => 'number',
            'label'         => __( 'H3 size', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 16,
            'input_attrs' => array(
                'min'   => 10,
                'max'   => 60,
                'step'  => 1,
                'style' => 'margin-bottom: 15px; padding: 10px;',
            ),            
        ), 
        'h4_size' => array(
            'slug'          => 'h4_size',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'absint',
            'default'       => '18',
            'type'          => 'number',
            'label'         => __( 'H4 size', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 17,
            'input_attrs' => array(
                'min'   => 10,
                'max'   => 60,
                'step'  => 1,
                'style' => 'margin-bottom: 15px; padding: 10px;',
            ),            
        ),  
        'h5_size' => array(
            'slug'          => 'h5_size',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'absint',
            'default'       => '14',
            'type'          => 'number',
            'label'         => __( 'H5 size', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 18,
            'input_attrs' => array(
                'min'   => 10,
                'max'   => 60,
                'step'  => 1,
                'style' => 'margin-bottom: 15px; padding: 10px;',
            ),            
        ),     
        'h6_size' => array(
            'slug'          => 'h6_size',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'absint',
            'default'       => '12',
            'type'          => 'number',
            'label'         => __( 'H6 size', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 19,
            'input_attrs' => array(
                'min'   => 10,
                'max'   => 60,
                'step'  => 1,
                'style' => 'margin-bottom: 15px; padding: 10px;',
            ),            
        ),  
        'body_size' => array(
            'slug'          => 'body_size',
            'section'       => 'rikke_fonts',
            'sanitize'      => 'absint',
            'default'       => '16',
            'type'          => 'number',
            'label'         => __( 'Body size', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 20,
            'input_attrs' => array(
                'min'   => 10,
                'max'   => 60,
                'step'  => 1,
                'style' => 'margin-bottom: 15px; padding: 10px;',
            ),            
        ),
        //Colors
        'color_primary' => array(
            'slug'          => 'color_primary',
            'section'       => 'colors',
            'sanitize'      => 'sanitize_hex_color',
            'default'       => '#EACB7F',
            'type'          => 'color',
            'label'         => __( 'Primary', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 11,
        ),
        'color_site_title' => array(
            'slug'          => 'color_site_title',
            'section'       => 'colors',
            'sanitize'      => 'sanitize_hex_color',
            'default'       => '#ffffff',
            'type'          => 'color',
            'label'         => __( 'Site title', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 12,
        ),
        'color_site_description' => array(
            'slug'          => 'color_site_description',
            'section'       => 'colors',
            'sanitize'      => 'sanitize_hex_color',
            'default'       => '#8C8A8A',
            'type'          => 'color',
            'label'         => __( 'Site description', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 13,
        ),        
        'background_header' => array(
            'slug'          => 'background_header',
            'section'       => 'colors',
            'sanitize'      => 'sanitize_hex_color',
            'default'       => '#000',
            'type'          => 'color',
            'label'         => __( 'Header background', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 16,
        ),
        'color_body' => array(
            'slug'          => 'color_body',
            'section'       => 'colors',
            'sanitize'      => 'sanitize_hex_color',
            'default'       => '#000',
            'type'          => 'color',
            'label'         => __( 'Body text', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 17,
        ),
        'background_footer' => array(
            'slug'          => 'background_footer',
            'section'       => 'colors',
            'sanitize'      => 'sanitize_hex_color',
            'default'       => '#000',
            'type'          => 'color',
            'label'         => __( 'Footer background', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 18,
        ),
        'color_footer' => array(
            'slug'          => 'color_footer',
            'section'       => 'colors',
            'sanitize'      => 'sanitize_hex_color',
            'default'       => '#ffffff',
            'type'          => 'color',
            'label'         => __( 'Footer color', 'rikke' ),
            'description'   => '',
            'choices'       => '',
            'priority'      => 19,
        ),

    );

    foreach ( $controls as $key => $control ) {
        if ($control['type'] != 'number') {
            $wp_customize->add_setting(
                $control['slug'],
                array(
                    'default'           => $control['default'],
                    'sanitize_callback' => $control['sanitize'],
                )
            );
            $wp_customize->add_control(
                $control['slug'],
                array(
                    'type'        => $control['type'],
                    'label'       => $control['label'],
                    'section'     => $control['section'],
                    'description' => $control['description'],
                    'choices'     => $control['choices'],
                    'priority'    => $control['priority'],
                )
            );
        } else {
            $wp_customize->add_setting(
                $control['slug'],
                array(
                    'default'           => $control['default'],
                    'sanitize_callback' => $control['sanitize'],
                )
            );
            $wp_customize->add_control(
                $control['slug'],
                array(
                    'type'        => $control['type'],
                    'label'       => $control['label'],
                    'section'     => $control['section'],
                    'description' => $control['description'],
                    'input_attrs' => array(
                        'min'   => 0,
                        'max'   => 200,
                        'step'  => 1,
                        'style' => '',
                    ),  
                    'priority'    => $control['priority'],                     
                )
            );            
        }
    }
}
add_action( 'customize_register', 'rikke_customize_register' );

/**
* Sanitize
*/

//Text
function rikke_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}
//Checkboxes
function rikke_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}
//Footer widget areas
function rikke_sanitize_fwidgets( $input ) {
    if ( in_array( $input, array( '1', '2', '3' ), true ) ) {
        return $input;
    }
}
//Blog layout
function rikke_sanitize_blog( $input ) {
    if ( in_array( $input, array( 'default', 'masonry-layout' ), true ) ) {
        return $input;
    }
}
//Sidebar position
function rikke_sanitize_sidebar( $input ) {
    if ( in_array( $input, array( 'left', 'right'), true ) ) {
        return $input;
    }
}
//Footer widget areas
function rikke_sanitize_widgets( $input ) {
    if ( in_array( $input, array( '1', '2', '3' ), true ) ) {
        return $input;
    }
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function rikke_customize_preview_js() {
	wp_enqueue_script( 'rikke_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'rikke_customize_preview_js' );