<?php
/**
 * @package Rikke
 */

//Converts hex colors to rgba for the menu background color
function rikke_hex2rgba($color, $opacity = false) {

        if ($color[0] == '#' ) {
        	$color = substr( $color, 1 );
        }
        $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
        $rgb =  array_map('hexdec', $hex);
        $opacity = 0.9;
        $output = 'rgba('.implode(",",$rgb).','.$opacity.')';

        return $output;
}


//Dynamic styles
function rikke_custom_styles($custom) {

	$custom = '';

	//Sidebar
	$sidebar_position = get_theme_mod('sidebar_position', 'right');
	if ($sidebar_position == 'left') {
		$custom .= "@media only screen and (min-width: 991px) { .content-area { float:right;}"."\n".".widget-area { float:left;}}"."\n";
	}

	//Fonts
	$headings_font 	= get_theme_mod('headings_font_family', 'Josefin Sans');
	$body_font 		= get_theme_mod('body_font_family', 'Inconsolata');	
	$custom 	.= "body { font-family:" . esc_attr(ucwords(strtolower($body_font))) . ";}"."\n";
	$custom 	.= "h1,h2,h3,h4,h5,h6,.site-title { font-family:" . esc_attr(ucwords(strtolower($headings_font))) . ";}"."\n";

	//Font sizes
	$h1_size = get_theme_mod( 'h1_size', '36' );
	$custom .= "h1, .site-title { font-size:" . intval($h1_size) . "px; }"."\n";
    $h2_size = get_theme_mod( 'h2_size', '30' );
    $custom .= "h2 { font-size:" . intval($h2_size) . "px; }"."\n";
    $h3_size = get_theme_mod( 'h3_size', '24' );
    $custom .= "h3 { font-size:" . intval($h3_size) . "px; }"."\n";
    $h4_size = get_theme_mod( 'h4_size', '18' );
    $custom .= "h4 { font-size:" . intval($h4_size) . "px; }"."\n";
    $h5_size = get_theme_mod( 'h5_size', '14' );
    $custom .= "h5 { font-size:" . intval($h5_size) . "px; }"."\n";
    $h6_size = get_theme_mod( 'h6_size', '12' );
    $custom .= "h6 { font-size:" . intval($h6_size) . "px; }"."\n";
    $body_size = get_theme_mod( 'body_size', '16' );
    $custom .= "body { font-size:" . intval($body_size) . "px; }"."\n";

    //Colors

	$primary_color = get_theme_mod( 'color_primary', '#EACB7F' );
	if ( $primary_color != '#ED5A5A' ) {
		$custom .= "#main #dslc-content .dslc-staff-member .dslc-staff-member-social a:hover,.footer-widgets .widget a:hover,.site-footer a:hover,.contact-info .rikke-icon,.contact-social a:hover,.entry-footer .rikke-icon,.single-meta .rikke-icon,.entry-title a:hover,.slicknav_nav a:hover,.main-navigation a:hover,a,a:hover,a:focus { color:" . esc_attr($primary_color) . ";}"."\n";
		$custom .= ".comment-reply-link,.cat-links,.go-top,button,.button:not(.header-button),input[type=\"button\"],input[type=\"reset\"],input[type=\"submit\"],button:hover,.button:not(.header-button):hover,input[type=\"button\"]:hover,input[type=\"reset\"]:hover,input[type=\"submit\"]:hover,.mobile-nav .search-item,.search-item .rikke-icon,.widget-area .rikke_social_widget li a,.contact-data .rikke-icon { background-color:" . esc_attr($primary_color) . ";}"."\n";
	}
	$color_site_title = get_theme_mod( 'color_site_title', '#ffffff' );
	$custom .= ".site-title a { color:" . esc_attr($color_site_title) . ";}"."\n";	
	$color_site_description = get_theme_mod( 'color_site_description', '#8C8A8A' );
	$custom .= ".site-description { color:" . esc_attr($color_site_description) . ";}"."\n";
	$color_site_description = get_theme_mod( 'color_site_description', '#8C8A8A' );
	$custom .= ".site-description { color:" . esc_attr($color_site_description) . ";}"."\n";
	$background_header = get_theme_mod( 'background_header', '#000' );
	$custom .= ".main-navigation, .site-branding { background-color:" . esc_attr($background_header) . ";}"."\n";
	$color_body = get_theme_mod( 'color_body', '#000' );
	$custom .= "body, .widget, .widget a { color:" . esc_attr($color_body) . ";}"."\n";
	$background_footer = get_theme_mod( 'background_footer', '#000' );
	$custom .= ".site-footer { background-color:" . esc_attr($background_footer) . ";}"."\n";
	$color_footer = get_theme_mod( 'color_footer', '#ffffff' );
	$custom .= ".site-footer, .site-footer a { color:" . esc_attr($color_footer) . ";}"."\n";
	
	$hide_blog_images = get_theme_mod( 'index_feat_image' );
	if ( $hide_blog_images == 1 ) {
    	$custom .= ".has-post-thumbnail .post-inner { margin:0;}"."\n";		
	}


	//Output all the styles
	wp_add_inline_style( 'rikke-style', $custom );	
}
add_action( 'wp_enqueue_scripts', 'rikke_custom_styles' );